<?php
/**
 * Plugin Name: Location Share on Checkout by Prismasell
 * Plugin URI: https://www.prismasell.com/woocommerce-location-share
 * Description: Adds a location field to WooCommerce checkout, allowing customers to share their location with a Google Maps link.
 * Version: 1.0.0
 * Author: Prismasell
 * Author URI: https://www.prismasell.com
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: location-share-on-checkout-by-prismasell
 * Domain Path: /languages
 */

if (!defined('ABSPATH')) {
    exit;
}

// Add location field to checkout
add_action('woocommerce_before_checkout_billing_form', 'prismasell_lsoc_add_location_field');

function prismasell_lsoc_add_location_field($checkout)
{
    echo '<div id="wc-location-field"><h2>' . esc_html__('Share Your Location', 'location-share-on-checkout-by-prismasell') . '</h2>';

    // Container for input field and button
    echo '<div class="location-input-container">';

    // Nonce field for location sharing
    wp_nonce_field('wc_location_nonce_action', 'wc_location_nonce');

    // Input field for location (read-only)
    woocommerce_form_field('customer_location', array(
        'type' => 'text',
        'class' => array('form-row-wide', 'location-input'),
        'label' => esc_html__('Your location will appear here', 'location-share-on-checkout-by-prismasell'),
        'placeholder' => esc_html__('Location will be shared automatically', 'location-share-on-checkout-by-prismasell'),
        'custom_attributes' => array('readonly' => 'readonly'),
    ), $checkout->get_value('customer_location'));

    // Button inside the input field container
    echo '<button id="get-location-button" type="button" class="location-button">' . esc_html__('Share Current Location', 'location-share-on-checkout-by-prismasell') . '</button>';

    echo '</div>'; // Close container

    // Hidden field to store captured latitude and longitude
    woocommerce_form_field('customer_latlng', array('type' => 'hidden'));

    echo '</div>';
}

// Enqueue script for getting user location
add_action('wp_enqueue_scripts', 'prismasell_lsoc_enqueue_location_script');
function prismasell_lsoc_enqueue_location_script()
{
    if (is_checkout()) {
        wp_enqueue_script('prismasell-lsoc-location-script', plugins_url('/js/wc-location.js', __FILE__), array('jquery'), '1.0.5', true);
        wp_enqueue_style('prismasell-lsoc-location-style', plugins_url('/css/wc-location.css', __FILE__));
    }
}

// Save location data to order meta
add_action('woocommerce_checkout_update_order_meta', 'prismasell_lsoc_save_location_field');
function prismasell_lsoc_save_location_field($order_id)
{
    // Verify nonce, unslash and sanitize
    $nonce = isset($_POST['wc_location_nonce']) ? sanitize_text_field(wp_unslash($_POST['wc_location_nonce'])) : '';
    if (!wp_verify_nonce($nonce, 'wc_location_nonce_action')) {
        return;
    }

    if (!empty($_POST['customer_location'])) {
        $customer_location = sanitize_text_field(wp_unslash($_POST['customer_location']));
        update_post_meta($order_id, 'customer_location', $customer_location);
    }

    if (!empty($_POST['customer_latlng'])) {
        $customer_latlng = sanitize_text_field(wp_unslash($_POST['customer_latlng']));
        update_post_meta($order_id, 'customer_latlng', $customer_latlng);
    }
}

// Display location in admin order details
add_action('woocommerce_admin_order_data_after_billing_address', 'prismasell_lsoc_display_location_admin_order', 10, 1);
function prismasell_lsoc_display_location_admin_order($order)
{
    $location = get_post_meta($order->get_id(), 'customer_location', true);
    $latlng = get_post_meta($order->get_id(), 'customer_latlng', true);

    if ($location) {
        // Ensure the URL is a Google Maps link and display it
        if (strpos($location, 'https://www.google.com/maps') !== false) {
            echo '<p><strong>' . esc_html__('Customer Location', 'location-share-on-checkout-by-prismasell') . ':</strong> <a href="' . esc_url($location) . '" target="_blank" rel="noopener noreferrer">' . esc_html__('View on Google Maps', 'location-share-on-checkout-by-prismasell') . '</a></p>';
        } else {
            echo '<p><strong>' . esc_html__('Customer Location', 'location-share-on-checkout-by-prismasell') . ':</strong> ' . esc_html($location) . '</p>';
        }
    } else {
        echo '<p><strong>' . esc_html__('Customer Location', 'location-share-on-checkout-by-prismasell') . ':</strong> ' . esc_html__('Location not provided', 'location-share-on-checkout-by-prismasell') . '</p>';
    }
}
